Performs a multi-trait model with correlated errors (seemingly unrelated regressions), and generates results by trait in a list.
mt_gwas(pleio_results, save_at = NULL)object of class pleio_class (returned by pleioR() function).
character with directory and/or file name (.rdata) to save the results. This is useful when handling multiple results such as in parallel jobs.
list with by trait dataframes that contain results of the multi-trait model.